commit b48c6fb: Fix typos in code comments

GitHub noreply at github.com
Wed Apr 7 08:56:04 UTC 2021


Author: Kako, Chang
Date: 2021-04-07 13:00:14 +0800
URL: https://github.com/rspamd/rspamd/commit/b48c6fbdbf0c9ef0cc2d5c352adfb6c3a4b857fa (refs/pull/3707/head)

Fix typos in code comments

---
 rules/bounce.lua | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/rules/bounce.lua b/rules/bounce.lua
index 4055d7741..a6e159b16 100644
--- a/rules/bounce.lua
+++ b/rules/bounce.lua
@@ -43,7 +43,7 @@ config.regexp.SUBJ_BOUNCE_WORDS = {
   re = make_subj_bounce_keywords_re(),
   group = 'headers',
   score = 0.0,
-  description = 'Words/phrases typical for DNS'
+  description = 'Words/phrases typical for DSN'
 }
 
 rspamd_config.BOUNCE = {
@@ -53,7 +53,7 @@ rspamd_config.BOUNCE = {
       -- RFC 3464:
       -- Whenever an SMTP transaction is used to send a DSN, the MAIL FROM
       -- command MUST use a NULL return address, i.e., "MAIL FROM:<>"
       -- In practise it is almost always the case for DNS
       return false
     end
 
@@ -75,7 +75,7 @@ rspamd_config.BOUNCE = {
       -- Check common bounce senders
       if (from_user == 'postmaster' or from_user == 'mailer-daemon') then
         bounce_sender = from_user
       -- MDaemon >= 14.5 sends multipart/report (RFC 3464) DNS covered above,
       -- but older versions send non-standard bounces with localized subjects and they
       -- are still around
       elseif from_user == 'mdaemon' and task:has_header('X-MDDSN-Message') then
@@ -53,7 +53,7 @@ rspamd_config.BOUNCE = {
       -- Whenever an SMTP transaction is used to send a DSN, the MAIL FROM
       -- command MUST use a NULL return address, i.e., "MAIL FROM:<>"
-      -- In practise it is almost always the case for DNS
+      -- In practise it is almost always the case for DSN
       return false
     end
@@ -75,7 +75,7 @@ rspamd_config.BOUNCE = {
       if (from_user == 'postmaster' or from_user == 'mailer-daemon') then
         bounce_sender = from_user
-      -- MDaemon >= 14.5 sends multipart/report (RFC 3464) DNS covered above,
+      -- MDaemon >= 14.5 sends multipart/report (RFC 3464) DSN covered above,
       -- but older versions send non-standard bounces with localized subjects and they
       -- are still around


More information about the Commits mailing list